
# q-expansion of newform 3315.2.a.r, downloaded from the LMFDB on 23 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 3315
weight = 2
poly_data = [-1, -8, -11, 20, 7, -9, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0], 1], [[-4, -11, 19, 7, -9, -1, 1], 1], [[-7, -11, 20, 7, -9, -1, 1], 1], [[-8, -36, 34, 22, -17, -3, 2], 1], [[-12, -35, 52, 21, -26, -3, 3], 1], [[-13, -52, 53, 30, -26, -4, 3], 1]]

hecke_ring_character_values = None
aps_data = [[0, -1, 0, 0, 0, 0, 0], [-1, 0, 0, 0, 0, 0, 0], [1, 0, 0, 0, 0, 0, 0], [0, 1, 0, 0, 0, 0, 1], [-2, 0, 1, 0, 0, -1, 0], [-1, 0, 0, 0, 0, 0, 0], [1, 0, 0, 0, 0, 0, 0], [0, -1, -2, 0, 0, 0, -1], [1, 0, 1, 1, -2, 0, 1], [-4, 1, 1, 0, 0, 0, -1], [1, -1, 1, -1, 1, 2, 0], [-1, 2, -2, -1, 0, -1, -1], [-5, 0, 0, -1, -1, 0, 1], [-1, 0, -2, 1, 2, 0, -3], [2, 2, -1, -2, -1, 2, 0], [-2, 1, 1, -4, -1, 1, -1], [-3, 0, 2, -3, 0, 0, -3], [-2, -1, 2, 0, -2, 1, 3], [-2, 3, 2, -2, 1, -2, 1], [-3, -1, -1, -1, -3, 0, 0], [-5, -3, 2, 3, 3, -3, 0], [3, 4, 0, 1, 2, 2, 1], [1, -2, 1, -1, 4, 0, -3], [-3, 1, 1, 3, 1, -2, 2], [-2, 0, 0, 2, 3, 3, -2], [-3, 1, 3, 1, -1, 0, 4], [2, -5, 1, 4, 1, 0, -3], [1, -1, -3, 1, 0, 3, -4], [-4, 0, -2, 0, -1, -1, -2], [-2, 4, -4, 0, 0, 4, -2], [5, -1, -2, -1, -3, 2, 0], [0, 0, 1, 4, 6, -2, 2], [3, -3, -4, 5, -4, -2, 2], [-4, -1, 1, -2, 1, -2, -1], [-8, -3, -2, 2, -1, -2, 1], [4, 0, 0, 0, -1, 2, 2], [0, -1, 0, -2, -6, -1, 1], [5, -1, 1, -1, -3, -3, -2], [-2, -1, -1, 0, 0, -1, 1], [-7, 3, 3, -1, 0, 1, 4], [-7, -1, -3, 5, 5, 0, -2], [-6, -2, 2, 0, 3, -1, 0], [3, -2, -7, 1, -6, -2, 1], [-5, -1, 1, 5, 5, -2, 2], [-1, -5, 3, 3, 4, -1, 0], [0, -2, 3, 0, -5, -3, 2], [-1, 4, -8, -1, -2, 2, -3], [-4, 2, 2, -2, 3, 3, -2], [-5, -1, 4, -3, 4, -1, -2], [-6, 3, -7, -4, 2, 2, -5], [1, -5, 3, -1, -1, -4, 2], [4, 9, -1, -2, -1, 6, 3], [-4, -4, -2, 0, 2, 4, -2], [-5, 2, 1, 1, -1, 1, 3], [-1, -5, -1, 1, -7, -2, 2], [4, -4, 0, 6, -2, -3, 2], [-5, -3, -4, -5, 0, 2, -6], [-4, 2, 3, 0, 1, 1, 0], [-1, -1, -3, 5, -1, 0, 2], [-20, -2, 2, 2, 3, -3, -2], [-4, 6, -3, 8, 3, -2, 4], [1, -1, -2, 5, -3, -1, 4], [0, -13, -2, 0, -1, -4, -1], [-4, -15, -4, 6, -3, -1, 1], [0, 3, 1, 4, -5, -1, 5], [-6, 8, 2, 2, 1, 1, -2], [1, -7, 1, 5, -4, -6, 6], [-2, 2, 1, -8, 6, 1, -6], [16, -3, -12, -2, -4, 3, 1], [0, 3, -3, -2, -8, 0, 1], [2, 9, -3, -8, 0, 6, 1], [-8, 3, 5, -2, 1, 4, 1], [8, -7, 6, 4, 5, -4, 3], [-5, 6, 5, -1, 2, 0, 3], [1, -7, 9, 1, -1, 2, 6], [5, 0, -4, -7, -3, 4, 1], [3, -6, -1, 3, 5, -3, -5], [6, 1, -5, -10, -1, 7, -5], [-10, -9, 3, 4, -2, -4, 3], [-1, -8, 0, 3, 0, 1, 5], [-14, 0, 2, 2, 5, -2, 2], [0, -2, 1, -2, 1, -4, 2], [-5, -4, 0, 1, -2, 3, 1], [0, 11, -2, -10, -4, 3, 1], [5, 4, 10, 5, -3, -3, 9], [2, 4, 7, 4, -1, -1, 2], [-7, 0, 7, -7, 2, -4, 1], [1, -7, 3, 1, -2, -9, -4], [-7, 0, -3, -1, -3, 5, -3], [11, 4, 1, -3, -4, 0, 5], [14, -9, -2, -4, -3, 5, 1], [-6, 11, -4, -6, 0, 3, -1], [-2, -2, 5, -2, -9, 3, 6], [2, -1, -8, 2, -2, 3, -3], [6, 15, -2, -8, -3, 4, -3], [9, -3, 1, 7, -3, -8, 8], [-6, 8, 4, -12, 6, 2, -4], [-11, 3, -2, -1, 5, -7, -8], [-8, -1, 9, 0, 6, 3, -3], [-5, 3, 9, -9, 7, 2, -2], [-5, -9, 6, -1, 0, -10, 2], [5, -9, 1, 13, 3, -2, 2], [-12, -3, 4, -8, -2, -6, -1], [7, 2, -1, 11, 3, -1, -1], [10, -3, -5, 4, -6, -5, 5], [16, -6, 6, -6, -2, 2, -2], [8, 3, -7, 0, -4, 0, -3], [2, -2, -1, 4, 0, 3, 0], [9, 7, 1, -1, -5, -4, 2], [7, 2, 1, -1, -10, -6, 7], [12, -2, 5, -10, 2, 1, -2], [-1, -2, 7, 3, 10, 0, 1], [1, -1, -5, -9, 0, 3, -2], [2, -7, 2, 6, 3, -4, -1], [-3, -13, 5, 3, -1, -9, -2], [-4, 6, -11, 6, 6, 7, -8], [1, 2, -7, 1, -1, -2, 5], [-5, 3, 2, 7, 5, -2, 6], [-10, 6, 14, 2, 3, 1, 0], [-4, 8, -4, -2, -4, 0, 0], [0, 2, 7, 0, 2, -1, 4], [7, 6, -7, 1, 7, 7, -9], [-17, 3, -3, -9, -1, 2, -6], [5, -9, -10, 9, -7, -2, 2], [-15, 3, 3, -7, 6, -3, -10], [9, 2, -5, 3, -4, 4, -1], [2, 9, -8, -8, -3, 0, 1], [3, 1, -5, 17, 7, -5, 4], [-9, 0, -4, 1, 0, -8, -3], [-4, 5, 4, -4, -6, 1, 9], [4, -2, 11, -12, -3, 1, 0], [-14, 5, -3, -12, 7, 2, -3], [2, 16, -13, -8, -1, 5, -14], [6, -14, 6, 2, -3, 5, 0], [4, -11, -8, 2, -3, 0, 1], [3, -3, 2, -7, 6, 8, -10], [19, 1, -4, 1, 3, 11, 2], [-19, -5, 3, -3, -8, -2, 8], [1, -4, 14, 13, -3, -6, 5], [1, -5, -3, 5, 4, 1, -2], [-1, 0, 3, 7, 10, -2, 5], [-21, -3, 9, -3, -2, -5, 8], [4, 5, -3, 4, -2, 0, -7], [-13, 2, 12, -3, -3, -1, 3], [0, 5, -7, 14, -6, -2, 5], [-3, 21, 12, -1, 7, 3, 2], [-1, -4, -3, 7, -3, 5, 7], [10, 1, -8, -4, -3, 6, -5], [-2, -3, 7, 0, -3, -3, 13], [2, 9, 11, -2, 0, -2, 5], [-2, -10, 9, -2, -6, -3, -2], [-6, 1, -3, -4, 5, 9, -13], [3, -3, 10, -3, 0, -5, 10], [-19, -5, -5, 3, 7, 6, -2], [-14, 7, 7, -2, -2, 4, 5], [3, 4, 11, -7, -6, 5, 9], [-2, -13, 13, 6, -6, -6, 5], [-21, 9, 10, -5, 3, 9, 0], [-1, -2, -3, -1, 1, 3, 9], [-5, 1, -13, 3, 6, 5, -10], [1, 8, -8, 1, -5, -3, -1], [-4, -8, -1, -12, 1, 6, -12], [4, 8, 4, 6, 16, 6, -6], [9, 4, -3, -7, 8, 4, -11], [-7, -4, -1, 9, -1, -5, -3], [-17, 8, 2, -1, 3, 3, -3], [4, -8, -13, -2, -2, 2, -2], [-16, 8, 9, -2, 5, -4, 6], [-2, 5, -16, 2, 7, -6, -9], [2, -14, -4, -10, 4, 8, -8], [-7, 4, 12, -7, 6, -2, -11], [1, 3, 9, 5, -10, 3, 10], [11, 8, 2, 7, -4, 4, 9], [5, -8, 11, 7, -6, -6, 5], [7, -7, -5, 9, 2, -7, 0], [-1, 11, 3, 9, -3, 2, 2], [8, -4, -8, -4, 1, 1, -4], [-20, -4, -6, -2, 5, 7, -2], [-21, 2, 4, -5, 7, 5, -11], [-6, -4, -4, 6, 10, 4, -2], [15, -4, -5, 15, 0, -6, 1], [-6, 12, -4, -4, -4, -1, 4], [-2, -9, -25, 8, -5, 1, -3], [-8, 5, -3, 0, -8, 0, 5], [1, -7, -1, -3, 16, -7, -4], [-9, 13, 1, -3, -2, 1, 2], [-1, -3, 6, -7, -8, 4, 4], [8, -15, 4, -8, -8, -7, -1], [-17, -6, 15, 7, 5, -7, -7], [-5, 9, -4, 5, 1, -1, 12], [-9, 4, 14, -7, 0, -13, 9], [-7, 5, 12, -3, 1, -10, 8], [-5, -1, 4, -7, 5, -5, -4], [-12, 6, 6, -8, 6, -6, 4], [0, 13, -10, 4, 7, -2, 7], [4, -2, -18, 6, -1, -3, -6], [-8, 3, -2, -12, -10, -1, -7], [33, 5, 2, 5, 9, 1, 0], [-26, 7, -6, -8, -3, 4, 5], [2, 1, 11, -2, 3, 2, -5], [-13, 6, -10, -3, -6, 9, -3], [15, 11, -4, -5, 6, 3, -4], [10, 10, -12, 2, 7, 5, -10], [-14, -12, -1, 6, 3, 0, -2], [-15, 16, 4, 1, 1, -1, 15], [-11, 5, 2, -1, -3, -5, 6], [14, 3, 7, -6, -12, -9, 5], [14, 2, -5, 0, -11, 11, 8], [-8, -1, 5, 8, -9, -1, 3], [25, 19, 4, -7, -12, 6, 8], [-18, 11, 11, -4, 10, -8, 1], [12, -19, 6, 4, 5, -8, 1], [-10, -3, 3, -6, -2, 10, -1], [-5, 5, 12, 5, -1, -5, 4], [-12, -2, -9, -2, 4, -7, -8], [-9, -15, -9, 11, -14, -5, 8], [9, 2, -20, 5, -2, -2, -3], [-1, -5, 19, -3, 2, -3, 8], [6, -14, 1, 12, 1, -3, 18], [13, 8, -9, -15, -9, 7, 5], [5, -2, 13, -3, 4, 4, 3], [-26, -1, 6, -8, 0, 3, 7], [-3, 15, 5, -1, -2, -5, -6], [10, 9, -11, 8, 1, 10, -7], [5, 11, -1, -13, 13, 3, -16], [9, 13, -4, -19, -4, 6, 0], [-5, -16, 1, -1, 14, -14, -13], [3, 9, 0, 3, 3, -6, 4], [15, 14, -6, -5, -16, 0, 7], [-6, -9, 13, 6, 2, -6, -1], [5, 3, -19, 3, -10, 5, 2], [-16, 4, 5, -26, 5, 11, -8], [14, -6, 0, 18, -5, -4, 14], [4, -8, 14, 8, -11, -5, -2], [6, 6, -3, 6, 10, 0, -6], [-13, 16, -7, -7, 2, -4, -7], [-24, -4, 8, 0, -3, -15, -4], [3, -9, -15, 11, -11, 4, 10], [-12, -6, 16, -8, -7, -2, 14], [14, 0, -18, 0, 3, 7, 0], [-7, -10, 2, -19, -9, 3, -3], [-4, 6, -5, 2, 6, -9, -14], [-2, 8, -13, -10, 6, 12, 0], [19, 7, -3, -3, 5, -2, 2], [14, -6, -8, 2, 1, 9, 0], [-26, -6, 14, 12, 12, -3, -10], [6, -16, 4, -2, -3, -6, 4], [9, 5, -4, 5, -2, 18, 4], [2, -5, -2, 8, 3, -5, 11], [-1, 14, -11, -9, 1, 8, 1], [15, -9, 11, -7, -2, 1, -4], [-3, 0, -16, -3, -3, 12, -13], [-18, 16, -11, -2, -1, 0, 6], [-17, -1, -9, -3, -12, 1, 0], [8, 14, 17, -14, 0, 3, 4], [6, 2, -11, -2, 2, 6, -8], [17, -9, -5, -7, 2, 5, -14], [19, -5, -9, 7, -2, 6, -6], [-22, -2, 4, -2, 13, 1, 4], [-28, 13, 10, -12, 7, 8, 3], [27, 4, -1, 15, 0, -4, 11], [10, 2, -2, 2, 7, -8, 0], [12, -15, 4, 10, 2, 7, -7], [16, 0, -1, -2, 2, -13, 2], [29, -10, -13, 13, -13, 9, 7], [21, 0, -11, -3, -16, 4, 5], [10, -3, 0, 14, 1, -4, 19], [-4, 15, 8, 8, 16, -3, 5], [14, 1, 15, -4, -9, -8, 9], [-7, -2, -2, 3, 4, -5, -7], [-19, -1, 7, 5, 5, -2, -12], [10, -12, -18, 16, -4, -12, 0], [-28, 10, -12, -16, -4, 4, -6], [1, 21, -2, 3, 11, -1, 4], [1, -1, -15, -1, -3, 2, 4], [-5, 15, 11, 9, -1, 0, 10], [-13, 15, -2, 9, 3, -3, 10], [-19, -3, 4, -11, -7, -1, 10], [7, -11, -4, -3, 0, -2, -6], [11, -17, -1, 15, 4, -3, 6], [-7, -2, 4, -1, 1, 7, 3], [30, 13, 2, 0, -8, -5, 5], [6, 18, 2, -8, -3, 9, 6], [3, 9, -5, -7, -3, 0, 0], [-2, 8, -11, 6, -1, 5, 8], [16, 5, -6, -12, 1, 2, -1], [-6, 1, -13, 24, 5, -7, -5], [7, -25, -9, -7, -7, 2, -10], [-7, 23, -17, -13, 1, 7, 6], [-11, -5, -13, -7, -2, -3, -10], [0, 5, -1, 14, 3, -7, 17], [5, -14, 23, 5, -5, -5, 1], [19, 4, 6, -7, -5, 6, 11], [-7, -26, 4, 17, -3, -10, 7], [-10, 11, -17, 12, 10, -12, -11], [-24, 0, 13, 2, 6, -5, 2], [13, 13, -6, 3, 13, 15, -4], [23, 5, 0, 13, 9, 9, 0], [-4, -5, 2, -8, 8, 2, 5], [-15, 30, -11, -7, -4, 2, -11], [8, 11, 10, 0, -5, -4, 11], [-18, 12, -15, 14, -10, 1, 12], [6, -5, -7, 14, -1, -8, 9], [-23, -15, 1, 5, 0, 7, 2], [10, -13, 25, 8, 10, -9, 7], [13, -5, 6, 11, 10, -8, -2], [-10, -20, 4, 18, 1, -18, 6], [-6, -6, 4, -6, -17, -3, 16], [-24, 13, 1, -4, 0, -1, -3], [22, -3, 0, -6, -19, 4, 7], [39, 9, -1, 15, -5, 4, 6], [13, -5, -10, -9, -2, 18, -10], [-4, 15, 4, -10, 1, -6, -17], [-8, -15, 5, -4, -6, -9, -13], [18, -10, -16, 6, -3, 5, 0], [4, 25, 5, -2, -6, -2, 1], [13, -8, -10, -5, -2, 8, -23], [-10, -25, -3, 16, -7, -13, 1], [1, -27, 3, 13, 0, -1, 4], [-8, -21, 6, 12, 13, -2, 3], [15, 19, 0, -17, 8, 9, -16], [26, -4, -10, 12, -2, -6, 0], [28, -1, 18, -6, 0, -1, -1], [1, 5, -13, -21, -3, 6, 2], [14, 8, -2, 10, 14, -6, 4], [27, -5, -14, 1, -14, 4, -6], [-6, 16, -14, 4, -7, 13, -6], [8, 14, 16, -10, 0, 3, -2], [-39, -10, 3, -3, 5, -13, -7], [12, -2, 0, -2, -3, -19, 4], [-25, 16, 1, -3, -4, 2, 1], [5, 15, 13, -19, 1, -2, 4], [-6, -4, -19, 0, -9, 1, -2], [46, 9, -1, 12, 3, 9, 3], [-6, 24, -14, -8, 8, -6, -4], [-12, 16, -7, 0, -12, -2, 16], [-15, -1, 8, -5, 4, -2, -10], [-21, 0, -3, 3, -10, 4, 5], [-25, 24, 19, -1, 8, 8, -1], [9, -14, 6, 1, 13, -5, -17], [8, 5, 10, -6, 5, 4, 3], [31, 3, 3, 3, -2, -5, -4], [-33, 0, -6, 13, 5, 0, 11], [12, -23, 6, 6, -4, -13, 1], [7, 6, -11, -5, 1, -5, -19], [-9, -1, 5, -17, 14, 8, -24], [3, 4, -5, 15, 18, 0, -7], [17, 21, -1, -1, -6, 9, 16], [-2, 10, -3, -12, -6, 17, -10], [-11, 14, -11, -5, 11, -11, -5], [3, 5, -8, -7, 3, 8, 6], [-3, 10, -6, -17, -11, 6, -1], [35, -6, 1, 3, -3, -7, 9], [7, -18, -2, 29, 8, -13, 1], [2, 10, 4, -10, -4, 0, -8], [11, -12, -20, 7, -17, 2, 3], [14, -16, -11, 12, -5, -1, 8], [-43, 9, -8, -5, 5, -9, -10], [1, -6, -1, -15, 4, 2, -3], [-11, -2, 10, -11, 19, 14, -17], [-2, -1, 12, -10, -2, -5, -17], [-12, -21, -12, -2, 9, 2, -5], [13, -9, 19, 7, -1, 3, 4], [-20, 3, -4, -10, 7, 14, -17], [4, 0, -7, -2, 9, 11, -8], [7, 36, -1, -1, 11, 15, -5], [6, -2, 8, 0, 15, 1, -24], [35, -18, -3, 9, -3, -1, -11], [-10, -17, -6, 0, -1, 10, -11], [3, -16, 13, -1, -1, -7, 13], [44, 13, 3, -16, -13, 2, 13], [7, -12, -2, 3, -14, -14, 11], [16, -14, -10, 6, -2, -20, -12], [6, 9, 16, -18, 25, 0, -27], [-20, -11, 24, 8, 13, -18, 11], [11, -10, 9, 25, 18, -10, 11], [4, -8, 18, 6, 8, -1, 6], [-14, 15, 20, -4, 4, -5, 11], [14, -23, 24, 2, -1, -6, 1], [28, 2, 14, 14, 9, 1, 6], [-32, 16, 14, -2, 17, -9, -6], [10, -17, 9, -24, -26, 6, -1], [37, -13, -3, -5, 1, -5, -2], [-8, -8, -4, 2, -7, 7, -4], [-13, 30, 5, 13, 14, 6, -5], [0, 1, -27, 20, 8, -11, -11], [-7, -2, 19, 11, 14, -5, -5], [-63, 13, -1, 7, 5, -2, 2], [1, -9, 6, 9, 0, 3, -8], [40, -6, -2, -8, -7, 14, 2], [-21, 5, 1, -7, -4, -21, -10], [4, -21, -14, 10, -4, 7, -3], [-39, -10, 2, 13, 7, -5, 1], [-21, -10, -2, -3, -11, 5, -7], [37, 8, -24, -9, -3, 19, -1], [-6, 4, -12, 8, 8, 16, 4], [23, 10, -11, -5, 3, 0, 7], [22, 5, 2, 14, -11, 2, 1], [4, -18, 21, -8, -12, -20, -8], [-41, 3, 15, -13, 16, 1, -12], [-13, -18, -7, -1, 9, -7, -5], [29, -15, 2, 5, -8, -12, -12], [33, 10, 7, 1, 3, 1, 7], [8, 12, -14, 8, 19, 1, 4], [-3, 19, -1, 9, 7, -4, 0], [37, 0, -6, 5, -10, -4, -9], [-25, 0, -9, 21, 17, -13, -15], [-9, 0, -3, -5, -3, -3, 3], [-17, 23, 3, -9, 1, 2, -14], [-7, -4, -15, -1, -4, 2, 3], [-3, -6, 2, -17, 9, 16, -11], [8, 3, 5, 8, -14, -6, 21], [-15, 12, -13, -1, -10, -15, 3], [15, -14, -10, -11, -5, 11, -3], [17, -17, -17, 33, -10, -15, 18], [3, -33, 4, 3, -10, -20, -8], [-23, -30, 15, 25, 5, -11, -1], [-41, -23, 4, 11, -4, -14, 0], [21, -36, 9, -1, 1, -11, 5], [8, 5, -1, 6, -12, 3, 11], [15, 29, 5, -5, 2, -5, 8], [18, -2, -15, 6, -18, -7, 10], [19, 7, 12, 11, 8, 7, 14], [-11, -4, 3, -11, 8, 16, -7], [-3, 14, -8, 5, 10, -5, -11], [13, 21, -7, -19, -4, 3, 8], [24, -2, 2, 18, -22, -2, 10], [-4, 14, -17, -10, -27, 4, 14], [4, -5, 21, 4, -14, 1, 7], [-9, 20, 2, 11, 4, -4, 5]]
